@@ -6,6 +6,7 @@ from slai_cli import log, constants
 from slai_cli.modules.drive_client import DriveClient
 from slai.clients.project import get_project_client
 from slai.clients.identity import get_identity_client
+from slai.clients.cli import get_cli_client
 
 
 class LocalConfigHelper:
@@ -13,6 +14,8 @@ class LocalConfigHelper:
         self.local_path = os.getcwd()
         self.project_client = get_project_client(project_name=None)
         self.identity_client = get_identity_client()
+        self.cli_client = get_cli_client()
+
         self.user_info = self.identity_client.get_user()
 
         self.drive_integration_enabled = False
@@ -83,10 +86,15 @@ class LocalConfigHelper:
                     "project_google_drive_folder_id"
                 ],
             )
+
+            model_version = self.cli_client.retrieve_model_version_by_id(
+                model_version_id=model_version_id
+            )
+
             model_notebook_google_drive_file_id = self.drive_client.upload_model_notebook(
                 model_name=model_name,
                 model_google_drive_folder_id=model_google_drive_folder_id,
-                notebook_path=f"{cwd}/models/{model_name}/{model_version_id}/notebook.ipynb",
+                notebook_path=f"{cwd}/models/{model_name}/{model_version['name']}/notebook.ipynb",
             )
 
             self.update_google_drive_config(
